# This file was auto-generated by Fern from our API Definition.

import typing

from .....types.tool_call_sound_type import ToolCallSoundType

McpToolConfigOverrideUpdateRequestModelToolCallSound = typing.Union[ToolCallSoundType, typing.Literal["off"]]
