# This file was auto-generated by Fern from our API Definition.

import typing

WebhookEventType = typing.Union[
    typing.Literal["transcript", "audio", "call_initiation_failure", "unredacted_transcript", "unredacted_audio"],
    typing.Any,
]
