# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.text_to_dialogue_websocket_audio_chunk_multi import TextToDialogueWebsocketAudioChunkMulti
from ...types.text_to_dialogue_websocket_error import TextToDialogueWebsocketError
from ...types.text_to_dialogue_websocket_final_audio_for_turn_multi import TextToDialogueWebsocketFinalAudioForTurnMulti
from ...types.text_to_dialogue_websocket_final_multi import TextToDialogueWebsocketFinalMulti

ReceiveTextToDialogueWebsocketMessageMulti = typing.Union[
    TextToDialogueWebsocketAudioChunkMulti,
    TextToDialogueWebsocketFinalAudioForTurnMulti,
    TextToDialogueWebsocketFinalMulti,
    TextToDialogueWebsocketError,
]
