# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class VoicesNotPermittedWarning(UncheckedBaseModel):
    type: typing.Literal["voices_not_permitted"] = pydantic.Field(default="voices_not_permitted")
    """
    Identifies this warning; branch on it to read the fields below.
    """

    speaker_ids: typing.List[str] = pydantic.Field()
    """
    Speakers whose voices were not permitted for cloning. The dub used a replacement voice for each of them; the rest of the speakers are unaffected.
    """

    message: str = pydantic.Field()
    """
    Human-readable description of the warning, for display. The wording may change at any time; branch on `type` instead.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
