# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .analysis_scope import AnalysisScope


class AttachedUserDataCollectionRef(UncheckedBaseModel):
    analysis_item_id: str = pydantic.Field()
    """
    Id of the referenced user data-collection item.
    """

    version_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Pinned item version. None tracks the item's latest published version.
    """

    scope: typing.Optional[AnalysisScope] = pydantic.Field(default=None)
    """
    Transcript context ('conversation' or 'agent') used when running this item.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
