# This file was auto-generated by Fern from our API Definition.

import typing

AuthConnectionStatus = typing.Union[
    typing.Literal["active", "refresh_failed", "revoked", "credential_invalid"], typing.Any
]
