# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class VoiceAccentResponseModel(UncheckedBaseModel):
    accent: str = pydantic.Field()
    """
    The accent value used for filtering shared voices via the `accent` query parameter on `GET /v1/shared-voices`.
    """

    language: str = pydantic.Field()
    """
    The language code this accent belongs to, e.g. `en`.
    """

    code: str = pydantic.Field()
    """
    The full accent code, e.g. `en-american`.
    """

    name: str = pydantic.Field()
    """
    The human-readable accent name, e.g. `American`.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
