# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.translate_audio_output_error import TranslateAudioOutputError
from ...types.translate_audio_payload import TranslateAudioPayload
from ...types.translate_auth_error import TranslateAuthError
from ...types.translate_error_payload import TranslateErrorPayload
from ...types.translate_final_transcript_payload import TranslateFinalTranscriptPayload
from ...types.translate_input_error import TranslateInputError
from ...types.translate_partial_transcript_payload import TranslatePartialTranscriptPayload
from ...types.translate_queue_overflow_error import TranslateQueueOverflowError
from ...types.translate_rate_limited_error import TranslateRateLimitedError
from ...types.translate_session_started_payload import TranslateSessionStartedPayload
from ...types.translate_status_payload import TranslateStatusPayload
from ...types.translate_transcriber_error import TranslateTranscriberError
from ...types.translate_translation_error import TranslateTranslationError
from ...types.translate_translation_payload import TranslateTranslationPayload

ReceiveTranslateStreamMessage = typing.Union[
    TranslateSessionStartedPayload,
    TranslateStatusPayload,
    TranslatePartialTranscriptPayload,
    TranslateFinalTranscriptPayload,
    TranslateTranslationPayload,
    TranslateAudioPayload,
    TranslateErrorPayload,
    TranslateAuthError,
    TranslateRateLimitedError,
    TranslateQueueOverflowError,
    TranslateInputError,
    TranslateTranscriberError,
    TranslateTranslationError,
    TranslateAudioOutputError,
]
