# This file was auto-generated by Fern from our API Definition.

import typing

LlmLiteralJsonSchemaPropertyType = typing.Union[
    typing.Literal["boolean"],
    typing.Literal["string"],
    typing.Literal["integer"],
    typing.Literal["number"],
    typing.List[str],
]
