# This file was auto-generated by Fern from our API Definition.

import typing

ToolInterruptionMode = typing.Union[
    typing.Literal["allow", "disable_during_tool", "disable_during_tool_and_turn"], typing.Any
]
