# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ContextualUpdateInfo(UncheckedBaseModel):
    context_id: str = pydantic.Field()
    """
    Client-supplied identifier grouping related contextual updates.
    """

    is_superseded: typing.Optional[bool] = pydantic.Field(default=None)
    """
    True when this contextual update has been replaced by a newer update with the same context_id.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
