# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .detected_entity import DetectedEntity


class CommittedTranscriptEntitiesPayload(UncheckedBaseModel):
    """
    Payload for detected entities on a committed transcript.
    """

    message_type: typing.Literal["committed_transcript_entities"] = pydantic.Field(
        default="committed_transcript_entities"
    )
    """
    The message type identifier.
    """

    text: str = pydantic.Field()
    """
    The committed transcript text the entities were detected in.
    """

    entities: typing.List[DetectedEntity] = pydantic.Field()
    """
    Detected entities. Empty if none were found.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
