# This file was auto-generated by Fern from our API Definition.

import typing

PlatformCategory = typing.Union[
    typing.Literal["voice", "silence", "burst", "asr", "text_message", "reception", "other"], typing.Any
]
