# This file was auto-generated by Fern from our API Definition.

import typing

CrawlStatus = typing.Union[
    typing.Literal["queued", "processing", "succeeded", "failed", "skipped", "cancelled"], typing.Any
]
