# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .crawl_status import CrawlStatus
from .crawl_type import CrawlType


class GetCrawlJobResponseModel(UncheckedBaseModel):
    type: typing.Optional[CrawlType] = None
    seed_url: str
    pattern: typing.Optional[str] = None
    max_depth: int
    max_pages: int
    status: typing.Optional[CrawlStatus] = None
    pages_identified: typing.Optional[int] = None
    pages_scraped: typing.Optional[int] = None
    pages_skipped: typing.Optional[int] = None
    pages_failed: typing.Optional[int] = None
    root_folder_id: str
    updated_at: int
    id: str
    created_at: int

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
