# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DubbingSegmentUpdateRequest(UncheckedBaseModel):
    """
    A partial update to a source segment; omitted fields are left unchanged.
    """

    text: typing.Optional[str] = pydantic.Field(default=None)
    """
    New text for the segment.
    """

    speaker_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    New speaker id for the segment.
    """

    start_s: typing.Optional[float] = pydantic.Field(default=None)
    """
    New start time, in seconds.
    """

    end_s: typing.Optional[float] = pydantic.Field(default=None)
    """
    New end time, in seconds.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
