# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel


class AstDivisionOperatorNodeOutput(UncheckedBaseModel):
    left: "AstNodeOutput" = pydantic.Field()
    """
    Left operand of the binary operator.
    """

    right: "AstNodeOutput" = pydantic.Field()
    """
    Right operand of the binary operator.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .ast_addition_operator_node_output import AstAdditionOperatorNodeOutput  # noqa: E402, I001
from .ast_and_operator_node_output import AstAndOperatorNodeOutput  # noqa: E402, I001
from .ast_conditional_operator_node_output import AstConditionalOperatorNodeOutput  # noqa: E402, I001
from .ast_equals_operator_node_output import AstEqualsOperatorNodeOutput  # noqa: E402, I001
from .ast_greater_than_operator_node_output import AstGreaterThanOperatorNodeOutput  # noqa: E402, I001
from .ast_greater_than_or_equals_operator_node_output import AstGreaterThanOrEqualsOperatorNodeOutput  # noqa: E402, I001
from .ast_less_than_operator_node_output import AstLessThanOperatorNodeOutput  # noqa: E402, I001
from .ast_less_than_or_equals_operator_node_output import AstLessThanOrEqualsOperatorNodeOutput  # noqa: E402, I001
from .ast_multiplication_operator_node_output import AstMultiplicationOperatorNodeOutput  # noqa: E402, I001
from .ast_node_output import AstNodeOutput  # noqa: E402, I001
from .ast_not_equals_operator_node_output import AstNotEqualsOperatorNodeOutput  # noqa: E402, I001
from .ast_or_operator_node_output import AstOrOperatorNodeOutput  # noqa: E402, I001
from .ast_subtraction_operator_node_output import AstSubtractionOperatorNodeOutput  # noqa: E402, I001

update_forward_refs(
    AstDivisionOperatorNodeOutput,
    AstAdditionOperatorNodeOutput=AstAdditionOperatorNodeOutput,
    AstAndOperatorNodeOutput=AstAndOperatorNodeOutput,
    AstConditionalOperatorNodeOutput=AstConditionalOperatorNodeOutput,
    AstEqualsOperatorNodeOutput=AstEqualsOperatorNodeOutput,
    AstGreaterThanOperatorNodeOutput=AstGreaterThanOperatorNodeOutput,
    AstGreaterThanOrEqualsOperatorNodeOutput=AstGreaterThanOrEqualsOperatorNodeOutput,
    AstLessThanOperatorNodeOutput=AstLessThanOperatorNodeOutput,
    AstLessThanOrEqualsOperatorNodeOutput=AstLessThanOrEqualsOperatorNodeOutput,
    AstMultiplicationOperatorNodeOutput=AstMultiplicationOperatorNodeOutput,
    AstNodeOutput=AstNodeOutput,
    AstNotEqualsOperatorNodeOutput=AstNotEqualsOperatorNodeOutput,
    AstOrOperatorNodeOutput=AstOrOperatorNodeOutput,
    AstSubtractionOperatorNodeOutput=AstSubtractionOperatorNodeOutput,
)
