# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .analysis_scope import AnalysisScope


class AttachedUserEvaluationRef(UncheckedBaseModel):
    analysis_item_id: str = pydantic.Field()
    """
    Id of the referenced user evaluation item.
    """

    version_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Primary item version whose result feeds scoring. None tracks the item's latest published version.
    """

    additional_version_ids: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    Extra item versions to also run for comparison (A/B). These are executed and stored but excluded from scoring; the primary version_id is the one that scores.
    """

    scope: typing.Optional[AnalysisScope] = pydantic.Field(default=None)
    """
    Transcript context ('conversation' or 'agent') used when running this item.
    """

    weight: typing.Optional[float] = pydantic.Field(default=None)
    """
    Optional relative weight for aggregate scoring.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
