# This file was auto-generated by Fern from our API Definition.

import typing

MusicFinetuneFailureReason = typing.Union[
    typing.Literal["audio_processing_failed", "copyright_violation", "training_failed"], typing.Any
]
