# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .conflict_section import ConflictSection


class FieldConflict(UncheckedBaseModel):
    path: str = pydantic.Field()
    """
    Identifier of the conflicting field relative to its section: a dot-path within conversation_config/platform_settings, or a procedure id.
    """

    section: ConflictSection = pydantic.Field()
    """
    Which config section this path belongs to.
    """

    base_value: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    Value at the common ancestor (merge base).
    """

    source_value: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    Value on the source branch tip.
    """

    target_value: typing.Optional[typing.Any] = pydantic.Field(default=None)
    """
    Value on the target branch tip.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
