# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class TtsConversationalConfigOverrideConfig(UncheckedBaseModel):
    model_id: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to allow overriding the model_id field.
    """

    voice_id: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to allow overriding the voice_id field.
    """

    stability: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to allow overriding the stability field.
    """

    speed: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to allow overriding the speed field.
    """

    similarity_boost: typing.Optional[bool] = pydantic.Field(default=None)
    """
    Whether to allow overriding the similarity_boost field.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
