# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel
from .array_json_schema_property_input_property_kind import ArrayJsonSchemaPropertyInputPropertyKind


class ArrayJsonSchemaPropertyInput(UncheckedBaseModel):
    property_kind: typing.Optional[ArrayJsonSchemaPropertyInputPropertyKind] = None
    description: typing.Optional[str] = None
    dynamic_variable: typing.Optional[str] = pydantic.Field(default=None)
    """
    When set, the entire parameter is populated from this dynamic variable at runtime. Mutually exclusive with description (LLM-provided value), constant_value, and is_omitted.
    """

    constant_value: typing.Optional[typing.List[typing.Any]] = pydantic.Field(default=None)
    """
    When set, the entire array uses this constant value at runtime. Mutually exclusive with description (LLM-provided array), dynamic_variable, and is_omitted.
    """

    is_omitted: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, this parameter will be completely omitted from the request. Only valid for optional parameters. Mutually exclusive with description, dynamic_variable, and constant_value.
    """

    type: typing.Optional[typing.Literal["array"]] = None
    items: typing.Optional["ArrayJsonSchemaPropertyInputItems"] = pydantic.Field(default=None)
    """
    Schema for array elements.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .array_json_schema_property_input_items import ArrayJsonSchemaPropertyInputItems  # noqa: E402, I001
from .object_json_schema_property_input import ObjectJsonSchemaPropertyInput  # noqa: E402, I001
from .object_json_schema_property_input_properties_value import ObjectJsonSchemaPropertyInputPropertiesValue  # noqa: E402, I001

update_forward_refs(
    ArrayJsonSchemaPropertyInput,
    ArrayJsonSchemaPropertyInputItems=ArrayJsonSchemaPropertyInputItems,
    ObjectJsonSchemaPropertyInput=ObjectJsonSchemaPropertyInput,
    ObjectJsonSchemaPropertyInputPropertiesValue=ObjectJsonSchemaPropertyInputPropertiesValue,
)
