# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DtmfInputConfig(UncheckedBaseModel):
    """
    Configuration for DTMF (keypad) input collection during phone calls.
    """

    dtmf_input_timeout: typing.Optional[float] = pydantic.Field(default=None)
    """
    Timeout in seconds to wait for additional DTMF digits
    """

    hash_terminator: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, pressing # immediately completes DTMF input
    """

    redact_input: typing.Optional[bool] = pydantic.Field(default=None)
    """
    If true, replace the caller's DTMF (keypad) entries with a redaction marker in the transcript, conversation log and analysis. Digits the agent repeats back or passes to a tool are not affected.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
