# This file was auto-generated by Fern from our API Definition.

import typing

UsersSortBy = typing.Union[
    typing.Literal["last_contact_unix_secs", "conversation_count", "average_sentiment_score"], typing.Any
]
