# This file was auto-generated by Fern from our API Definition.

import typing

MusicFinetuneStatus = typing.Union[
    typing.Literal["pending", "in_progress", "completed", "failed", "blocked"], typing.Any
]
