# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .analysis_scope import AnalysisScope
from .attached_system_evaluation_ref_analysis_item_id import AttachedSystemEvaluationRefAnalysisItemId


class AttachedSystemEvaluationRef(UncheckedBaseModel):
    analysis_item_id: AttachedSystemEvaluationRefAnalysisItemId = pydantic.Field()
    """
    Id of the referenced built-in system evaluation.
    """

    scope: typing.Optional[AnalysisScope] = pydantic.Field(default=None)
    """
    Transcript context ('conversation' or 'agent') used when running this item.
    """

    weight: typing.Optional[float] = pydantic.Field(default=None)
    """
    Optional relative weight for aggregate scoring.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
