# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DubbingTargetTranscriptSegment(UncheckedBaseModel):
    """
    One segment of a target transcript: a source segment plus its translation.
    """

    id: str = pydantic.Field()
    """
    Stable identifier of the segment (from the source).
    """

    speaker_id: str = pydantic.Field()
    """
    Identifier of the segment's speaker.
    """

    start_s: float = pydantic.Field()
    """
    Start time of the segment, in seconds.
    """

    end_s: float = pydantic.Field()
    """
    End time of the segment, in seconds.
    """

    source_text: str = pydantic.Field()
    """
    The source-language text of the segment.
    """

    translation: typing.Optional[str] = pydantic.Field(default=None)
    """
    The translated text, or null if not translated yet (needs translation).
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
