# This file was auto-generated by Fern from our API Definition.

import typing

LlmReasoningEffort = typing.Union[
    typing.Literal["none", "minimal", "low", "medium", "high", "xhigh", "max"], typing.Any
]
