# This file was auto-generated by Fern from our API Definition.

import typing

ConflictSection = typing.Union[
    typing.Literal["conversation_config", "platform_settings", "procedures", "workflow"], typing.Any
]
