# This file was auto-generated by Fern from our API Definition.

import typing

from .tool_call_sound_type import ToolCallSoundType

McpToolConfigOverrideOutputToolCallSound = typing.Union[ToolCallSoundType, typing.Literal["off"]]
