# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.translate_end_of_stream_payload import TranslateEndOfStreamPayload
from ...types.translate_input_audio_chunk_payload import TranslateInputAudioChunkPayload

SendTranslateStreamMessage = typing.Union[TranslateInputAudioChunkPayload, TranslateEndOfStreamPayload]
