# This file was auto-generated by Fern from our API Definition.

import typing

DubbingProjectResponseStatus = typing.Union[
    typing.Literal["queued", "preparing", "processing", "ready", "failed"], typing.Any
]
