# This file was auto-generated by Fern from our API Definition.

import typing

DubbingLanguageResponseStatus = typing.Union[
    typing.Literal["queued", "processing", "completed", "stale", "failed"], typing.Any
]
