# This file was auto-generated by Fern from our API Definition.

import typing

BodyEditServiceAccountApiKeyV1ServiceAccountsServiceAccountUserIdApiKeysApiKeyIdPatchThirdPartyDisableAllowed = (
    typing.Union[bool, typing.Literal["clear"], typing.Literal["no_update"]]
)
