# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .dubbing_target_transcript_segment import DubbingTargetTranscriptSegment


class DubbingTargetTranscriptResponse(UncheckedBaseModel):
    source_language: typing.Optional[str] = pydantic.Field(default=None)
    """
    BCP-47 language tag of the source transcript.
    """

    target_language: str = pydantic.Field()
    """
    BCP-47 language tag this target is translated into.
    """

    segments: typing.List[DubbingTargetTranscriptSegment] = pydantic.Field()
    """
    The target segments, in playback order.
    """

    revision: int = pydantic.Field()
    """
    The target's revision at read time.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
