# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .auth_connection_dependencies import AuthConnectionDependencies
from .auth_connection_status import AuthConnectionStatus
from .o_auth_2_jwt_response_algorithm import OAuth2JwtResponseAlgorithm
from .o_auth_2_jwt_response_token_response_field import OAuth2JwtResponseTokenResponseField


class OAuth2JwtResponse(UncheckedBaseModel):
    """
    Response model for OAuth2 JWT auth connections
    """

    name: str
    provider: str
    algorithm: typing.Optional[OAuth2JwtResponseAlgorithm] = pydantic.Field(default=None)
    """
    JWT signing algorithm
    """

    key_id: typing.Optional[str] = pydantic.Field(default=None)
    """
    Key ID (kid) for JWT header - useful for key rotation
    """

    issuer: str = pydantic.Field()
    """
    JWT issuer (iss claim)
    """

    audience: str = pydantic.Field()
    """
    JWT audience (aud claim)
    """

    subject: str = pydantic.Field()
    """
    JWT subject (sub claim)
    """

    expiration_seconds: typing.Optional[int] = pydantic.Field(default=None)
    """
    Token expiration time in seconds
    """

    extra_params: typing.Optional[typing.Dict[str, str]] = pydantic.Field(default=None)
    """
    Additional custom claims to include in the JWT
    """

    token_url: str = pydantic.Field()
    """
    Token endpoint URL for exchanging JWT for access token
    """

    scopes: typing.Optional[typing.List[str]] = pydantic.Field(default=None)
    """
    OAuth2 scopes to request when exchanging JWT for access token
    """

    token_response_field: typing.Optional[OAuth2JwtResponseTokenResponseField] = pydantic.Field(default=None)
    """
    Token field to extract from the token endpoint response.
    """

    id: str
    used_by: typing.Optional[AuthConnectionDependencies] = None
    status: typing.Optional[AuthConnectionStatus] = None
    status_detail: typing.Optional[str] = None
    status_updated_at: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
