# This file was auto-generated by Fern from our API Definition.

import typing

ConstantSchemaOverrideConstantValue = typing.Union[
    str, int, float, bool, typing.List[typing.Any], typing.Dict[str, typing.Any]
]
