# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel


class SubAgentInput(UncheckedBaseModel):
    agent_id: str
    branch_id: typing.Optional[str] = None
    description: str
    parameters: typing.Optional["ObjectJsonSchemaPropertyInput"] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .array_json_schema_property_input import ArrayJsonSchemaPropertyInput  # noqa: E402, I001
from .array_json_schema_property_input_items import ArrayJsonSchemaPropertyInputItems  # noqa: E402, I001
from .object_json_schema_property_input import ObjectJsonSchemaPropertyInput  # noqa: E402, I001
from .object_json_schema_property_input_properties_value import ObjectJsonSchemaPropertyInputPropertiesValue  # noqa: E402, I001

update_forward_refs(
    SubAgentInput,
    ArrayJsonSchemaPropertyInput=ArrayJsonSchemaPropertyInput,
    ArrayJsonSchemaPropertyInputItems=ArrayJsonSchemaPropertyInputItems,
    ObjectJsonSchemaPropertyInput=ObjectJsonSchemaPropertyInput,
    ObjectJsonSchemaPropertyInputPropertiesValue=ObjectJsonSchemaPropertyInputPropertiesValue,
)
