# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .alerting_monitor_config import AlertingMonitorConfig
from .alerting_webhook_notifier_response import AlertingWebhookNotifierResponse


class AlertingSettingsResponse(UncheckedBaseModel):
    """
    Customer-facing view of alerting settings. Unlike AdminAlertingSettingsResponse,
    it has no internal_notifiers field: those are ElevenLabs-internal delivery
    channels whose URLs must never be returned outside the admin API.
    """

    monitor_configs: typing.Optional[typing.Dict[str, AlertingMonitorConfig]] = None
    auto_resolve_after_inactive_minutes: typing.Optional[int] = None
    notifiers: typing.Optional[typing.List[AlertingWebhookNotifierResponse]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
