# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel


class AstAdditionOperatorNodeInput(UncheckedBaseModel):
    left: "AstNodeInput" = pydantic.Field()
    """
    Left operand of the binary operator.
    """

    right: "AstNodeInput" = pydantic.Field()
    """
    Right operand of the binary operator.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .ast_and_operator_node_input import AstAndOperatorNodeInput  # noqa: E402, I001
from .ast_conditional_operator_node_input import AstConditionalOperatorNodeInput  # noqa: E402, I001
from .ast_division_operator_node_input import AstDivisionOperatorNodeInput  # noqa: E402, I001
from .ast_equals_operator_node_input import AstEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_greater_than_operator_node_input import AstGreaterThanOperatorNodeInput  # noqa: E402, I001
from .ast_greater_than_or_equals_operator_node_input import AstGreaterThanOrEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_less_than_operator_node_input import AstLessThanOperatorNodeInput  # noqa: E402, I001
from .ast_less_than_or_equals_operator_node_input import AstLessThanOrEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_multiplication_operator_node_input import AstMultiplicationOperatorNodeInput  # noqa: E402, I001
from .ast_node_input import AstNodeInput  # noqa: E402, I001
from .ast_not_equals_operator_node_input import AstNotEqualsOperatorNodeInput  # noqa: E402, I001
from .ast_or_operator_node_input import AstOrOperatorNodeInput  # noqa: E402, I001
from .ast_subtraction_operator_node_input import AstSubtractionOperatorNodeInput  # noqa: E402, I001

update_forward_refs(
    AstAdditionOperatorNodeInput,
    AstAndOperatorNodeInput=AstAndOperatorNodeInput,
    AstConditionalOperatorNodeInput=AstConditionalOperatorNodeInput,
    AstDivisionOperatorNodeInput=AstDivisionOperatorNodeInput,
    AstEqualsOperatorNodeInput=AstEqualsOperatorNodeInput,
    AstGreaterThanOperatorNodeInput=AstGreaterThanOperatorNodeInput,
    AstGreaterThanOrEqualsOperatorNodeInput=AstGreaterThanOrEqualsOperatorNodeInput,
    AstLessThanOperatorNodeInput=AstLessThanOperatorNodeInput,
    AstLessThanOrEqualsOperatorNodeInput=AstLessThanOrEqualsOperatorNodeInput,
    AstMultiplicationOperatorNodeInput=AstMultiplicationOperatorNodeInput,
    AstNodeInput=AstNodeInput,
    AstNotEqualsOperatorNodeInput=AstNotEqualsOperatorNodeInput,
    AstOrOperatorNodeInput=AstOrOperatorNodeInput,
    AstSubtractionOperatorNodeInput=AstSubtractionOperatorNodeInput,
)
