# This file was auto-generated by Fern from our API Definition.

import typing

AttachedSystemEvaluationRefAnalysisItemId = typing.Union[
    typing.Literal["__system_eval_criteria_sentiment", "__system_eval_criteria_frustration"], typing.Any
]
