# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .dynamic_variable_update_common_model import DynamicVariableUpdateCommonModel


class ConversationHistoryTranscriptApiIntegrationWebhookToolsResultCommonModelOutput(UncheckedBaseModel):
    request_id: str
    tool_name: str
    result_value: str
    is_error: bool
    is_blocked: bool
    tool_has_been_called: bool
    tool_latency_secs: float
    error_type: str
    raw_error_message: str
    dynamic_variable_updates: typing.List[DynamicVariableUpdateCommonModel]
    type: typing.Literal["api_integration_webhook"] = "api_integration_webhook"
    integration_id: str
    credential_id: str
    integration_connection_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
