# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .default_sharing_group_config_permission_level import DefaultSharingGroupConfigPermissionLevel


class DefaultSharingGroupConfig(UncheckedBaseModel):
    group_id: str = pydantic.Field()
    """
    The ID of the group to share with
    """

    permission_level: DefaultSharingGroupConfigPermissionLevel = pydantic.Field()
    """
    The permission level to grant to the group
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
