# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class ScribeSessionTimeLimitExceededErrorPayload(UncheckedBaseModel):
    """
    Payload for session time limit exceeded errors.
    """

    message_type: typing.Literal["session_time_limit_exceeded"] = pydantic.Field(default="session_time_limit_exceeded")
    """
    The message type identifier.
    """

    error: str = pydantic.Field()
    """
    Session time limit exceeded error details.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
