# This file was auto-generated by Fern from our API Definition.

import typing

FinalTranscriptWithTimestampsWordsItemType = typing.Union[typing.Literal["word", "spacing", "audio_event"], typing.Any]
