# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .agent_test_folder_path_segment_response_model import AgentTestFolderPathSegmentResponseModel


class GetAgentTestFolderResponseModel(UncheckedBaseModel):
    id: str
    name: str
    folder_path: typing.Optional[typing.List[AgentTestFolderPathSegmentResponseModel]] = pydantic.Field(default=None)
    """
    The path from the root folder to the current folder.
    """

    children_count: typing.Optional[int] = pydantic.Field(default=None)
    """
    The number of direct children (tests and subfolders) in this folder
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
