# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .environment_variable_response_type import EnvironmentVariableResponseType
from .environment_variable_response_values import EnvironmentVariableResponseValues


class EnvironmentVariableResponse(UncheckedBaseModel):
    label: str
    created_at_unix_secs: int
    updated_at_unix_secs: int
    created_by_user_id: typing.Optional[str] = None
    type: EnvironmentVariableResponseType
    id: str
    workspace_id: str
    values: EnvironmentVariableResponseValues

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
