# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel
from .translated_string import TranslatedString


class SayNodeLiteralMessageInput(UncheckedBaseModel):
    type: typing.Optional[typing.Literal["literal"]] = None
    text: str = pydantic.Field()
    """
    Literal text message to be spoken by the agent.
    """

    text_translations: typing.Optional[typing.Dict[str, TranslatedString]] = pydantic.Field(default=None)
    """
    Translations for the text field
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
