# This file was auto-generated by Fern from our API Definition.

import typing

WorkspaceWebhookEventType = typing.Union[
    typing.Literal["voice_library_removal_notice", "speech_to_text", "agent_qa"], typing.Any
]
