# This file was auto-generated by Fern from our API Definition.

from __future__ import annotations

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, update_forward_refs
from ..core.unchecked_base_model import UncheckedBaseModel


class CustomToolApiSchemaConfig(UncheckedBaseModel):
    """
    Parameter schema for an integration tool the brain answers itself.

    Unlike ``WebhookToolApiSchemaConfig`` there is no HTTP transport: ``handler``
    receives the LLM's parameters and produces the tool result.
    """

    request_body_schema: "ObjectJsonSchemaPropertyOutput" = pydantic.Field()
    """
    JSON schema for the parameters the LLM provides to this tool.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow


from .array_json_schema_property_output import ArrayJsonSchemaPropertyOutput  # noqa: E402, I001
from .array_json_schema_property_output_items import ArrayJsonSchemaPropertyOutputItems  # noqa: E402, I001
from .object_json_schema_property_output import ObjectJsonSchemaPropertyOutput  # noqa: E402, I001
from .object_json_schema_property_output_properties_value import ObjectJsonSchemaPropertyOutputPropertiesValue  # noqa: E402, I001

update_forward_refs(
    CustomToolApiSchemaConfig,
    ArrayJsonSchemaPropertyOutput=ArrayJsonSchemaPropertyOutput,
    ArrayJsonSchemaPropertyOutputItems=ArrayJsonSchemaPropertyOutputItems,
    ObjectJsonSchemaPropertyOutput=ObjectJsonSchemaPropertyOutput,
    ObjectJsonSchemaPropertyOutputPropertiesValue=ObjectJsonSchemaPropertyOutputPropertiesValue,
)
