# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2
from ..core.unchecked_base_model import UncheckedBaseModel


class DubbingLanguageOutputs(UncheckedBaseModel):
    """
    Signed, time-limited download URLs for a language target's outputs.
    """

    lossless_audio: typing.Optional[str] = pydantic.Field(default=None)
    """
    Signed URL of the dubbed lossless audio track.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
